@@ -1,6 +1,6 @@
 shape <-
 function (xx, xlab = deparse(substitute(xx)), log = FALSE, xlim = NULL, 
-    nclass = "Scott", ifbw = FALSE, wend = 0.05, ifnright = TRUE, 
+    nclass = NULL, ifbw = FALSE, wend = 0.05, ifnright = TRUE, 
     colr = 8, cex = 0.8, ...) 
 {
     frame()
@@ -9,6 +9,9 @@ function (xx, xlab = deparse(substitute(xx)), log = FALSE, xlim = NULL,
     par(mfrow = c(2, 2), pty = "m", cex.main = 0.9)
     temp.x <- remove.na(xx)
     x <- temp.x$x[1:temp.x$n]
+    nobs <- temp.x$n
+    if ((is.null(nclass)) && (nobs <= 500)) nclass <- "scott"
+    if ((is.null(nclass)) && (nobs > 500)) nclass <- "fd"
     save <- gx.hist(x, xlab = xlab, ylab = " ", log = log, xlim = xlim, 
         main = "Histogram", nclass = nclass, ifnright = ifnright, 
         cex = cex, colr = colr, ...)
